# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEntityResult',
    'AwaitableGetEntityResult',
    'get_entity',
    'get_entity_output',
]

@pulumi.output_type
class GetEntityResult:
    """
    A collection of values returned by getEntity.
    """
    def __init__(__self__, account_id=None, application_id=None, domain=None, entity_tags=None, guid=None, id=None, ignore_case=None, ignore_not_found=None, name=None, serving_apm_application_id=None, tags=None, type=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if domain and not isinstance(domain, str):
            raise TypeError("Expected argument 'domain' to be a str")
        pulumi.set(__self__, "domain", domain)
        if entity_tags and not isinstance(entity_tags, str):
            raise TypeError("Expected argument 'entity_tags' to be a str")
        pulumi.set(__self__, "entity_tags", entity_tags)
        if guid and not isinstance(guid, str):
            raise TypeError("Expected argument 'guid' to be a str")
        pulumi.set(__self__, "guid", guid)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ignore_case and not isinstance(ignore_case, bool):
            raise TypeError("Expected argument 'ignore_case' to be a bool")
        pulumi.set(__self__, "ignore_case", ignore_case)
        if ignore_not_found and not isinstance(ignore_not_found, bool):
            raise TypeError("Expected argument 'ignore_not_found' to be a bool")
        pulumi.set(__self__, "ignore_not_found", ignore_not_found)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if serving_apm_application_id and not isinstance(serving_apm_application_id, str):
            raise TypeError("Expected argument 'serving_apm_application_id' to be a str")
        pulumi.set(__self__, "serving_apm_application_id", serving_apm_application_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> builtins.str:
        """
        The domain-specific application ID of the entity. Only returned for APM and Browser applications.
        """
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter
    def domain(self) -> builtins.str:
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="entityTags")
    def entity_tags(self) -> builtins.str:
        """
        A JSON-encoded string, comprising tags associated with the entity fetched.
        * See the **Additional Examples** section below, for an illustration depicting the usage of `jsondecode` with the attribute `entity_tags`, to get the tags associated with the entity fetched.
        """
        return pulumi.get(self, "entity_tags")

    @property
    @pulumi.getter
    def guid(self) -> builtins.str:
        """
        The unique GUID of the entity.
        """
        return pulumi.get(self, "guid")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ignoreCase")
    def ignore_case(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "ignore_case")

    @property
    @pulumi.getter(name="ignoreNotFound")
    def ignore_not_found(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "ignore_not_found")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="servingApmApplicationId")
    def serving_apm_application_id(self) -> builtins.str:
        """
        The browser-specific ID of the backing APM entity. Only returned for Browser applications.
        """
        return pulumi.get(self, "serving_apm_application_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Sequence['outputs.GetEntityTagResult']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")


class AwaitableGetEntityResult(GetEntityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEntityResult(
            account_id=self.account_id,
            application_id=self.application_id,
            domain=self.domain,
            entity_tags=self.entity_tags,
            guid=self.guid,
            id=self.id,
            ignore_case=self.ignore_case,
            ignore_not_found=self.ignore_not_found,
            name=self.name,
            serving_apm_application_id=self.serving_apm_application_id,
            tags=self.tags,
            type=self.type)


def get_entity(account_id: Optional[builtins.str] = None,
               domain: Optional[builtins.str] = None,
               entity_tags: Optional[builtins.str] = None,
               ignore_case: Optional[builtins.bool] = None,
               ignore_not_found: Optional[builtins.bool] = None,
               name: Optional[builtins.str] = None,
               tags: Optional[Sequence[Union['GetEntityTagArgs', 'GetEntityTagArgsDict']]] = None,
               type: Optional[builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEntityResult:
    """
    Use this data source to access information about an existing resource.

    :param builtins.str account_id: The New Relic account ID the entity to be returned would be associated with, i.e. if specified, the data source would filter matching entities received by `account_id` and return the first match. If not, matching entities are filtered by the account ID specified in the configuration of the provider. See the **Example: Filter By Account ID** section above for more details.
    :param builtins.str domain: The entity's domain. Valid values are APM, BROWSER, INFRA, MOBILE, SYNTH, and EXT. If not specified, all domains are searched.
    :param builtins.str entity_tags: A JSON-encoded string, comprising tags associated with the entity fetched.
           * See the **Additional Examples** section below, for an illustration depicting the usage of `jsondecode` with the attribute `entity_tags`, to get the tags associated with the entity fetched.
    :param builtins.bool ignore_case: Ignore case of the `name` when searching for the entity. Defaults to false.
    :param builtins.bool ignore_not_found: A boolean argument that, when set to true, prevents an error from being thrown when the queried entity is not found. Instead, a warning is displayed. Defaults to `false`.
           
           > **WARNING:** Setting the `ignore_not_found` argument to `true` will display an 'entity not found' warning instead of throwing an error. This can lead to downstream errors if the values of attributes exported by this data source are used elsewhere, as all of these values would be null. Please use this argument at your own risk.
    :param builtins.str name: The name of the entity in New Relic One.  The first entity matching this name for the given search parameters will be returned.
    :param Sequence[Union['GetEntityTagArgs', 'GetEntityTagArgsDict']] tags: A tag applied to the entity. See Nested tag blocks below for details.
    :param builtins.str type: The entity's type. Valid values are APPLICATION, DASHBOARD, HOST, MONITOR, WORKLOAD, AWSLAMBDAFUNCTION, SERVICE_LEVEL, and KEY_TRANSACTION. Note: Other entity types may also be queryable as the list of entity types may fluctuate over time.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['domain'] = domain
    __args__['entityTags'] = entity_tags
    __args__['ignoreCase'] = ignore_case
    __args__['ignoreNotFound'] = ignore_not_found
    __args__['name'] = name
    __args__['tags'] = tags
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getEntity:getEntity', __args__, opts=opts, typ=GetEntityResult).value

    return AwaitableGetEntityResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        application_id=pulumi.get(__ret__, 'application_id'),
        domain=pulumi.get(__ret__, 'domain'),
        entity_tags=pulumi.get(__ret__, 'entity_tags'),
        guid=pulumi.get(__ret__, 'guid'),
        id=pulumi.get(__ret__, 'id'),
        ignore_case=pulumi.get(__ret__, 'ignore_case'),
        ignore_not_found=pulumi.get(__ret__, 'ignore_not_found'),
        name=pulumi.get(__ret__, 'name'),
        serving_apm_application_id=pulumi.get(__ret__, 'serving_apm_application_id'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'))
def get_entity_output(account_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      domain: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      entity_tags: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      ignore_case: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                      ignore_not_found: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                      name: Optional[pulumi.Input[builtins.str]] = None,
                      tags: Optional[pulumi.Input[Optional[Sequence[Union['GetEntityTagArgs', 'GetEntityTagArgsDict']]]]] = None,
                      type: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEntityResult]:
    """
    Use this data source to access information about an existing resource.

    :param builtins.str account_id: The New Relic account ID the entity to be returned would be associated with, i.e. if specified, the data source would filter matching entities received by `account_id` and return the first match. If not, matching entities are filtered by the account ID specified in the configuration of the provider. See the **Example: Filter By Account ID** section above for more details.
    :param builtins.str domain: The entity's domain. Valid values are APM, BROWSER, INFRA, MOBILE, SYNTH, and EXT. If not specified, all domains are searched.
    :param builtins.str entity_tags: A JSON-encoded string, comprising tags associated with the entity fetched.
           * See the **Additional Examples** section below, for an illustration depicting the usage of `jsondecode` with the attribute `entity_tags`, to get the tags associated with the entity fetched.
    :param builtins.bool ignore_case: Ignore case of the `name` when searching for the entity. Defaults to false.
    :param builtins.bool ignore_not_found: A boolean argument that, when set to true, prevents an error from being thrown when the queried entity is not found. Instead, a warning is displayed. Defaults to `false`.
           
           > **WARNING:** Setting the `ignore_not_found` argument to `true` will display an 'entity not found' warning instead of throwing an error. This can lead to downstream errors if the values of attributes exported by this data source are used elsewhere, as all of these values would be null. Please use this argument at your own risk.
    :param builtins.str name: The name of the entity in New Relic One.  The first entity matching this name for the given search parameters will be returned.
    :param Sequence[Union['GetEntityTagArgs', 'GetEntityTagArgsDict']] tags: A tag applied to the entity. See Nested tag blocks below for details.
    :param builtins.str type: The entity's type. Valid values are APPLICATION, DASHBOARD, HOST, MONITOR, WORKLOAD, AWSLAMBDAFUNCTION, SERVICE_LEVEL, and KEY_TRANSACTION. Note: Other entity types may also be queryable as the list of entity types may fluctuate over time.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['domain'] = domain
    __args__['entityTags'] = entity_tags
    __args__['ignoreCase'] = ignore_case
    __args__['ignoreNotFound'] = ignore_not_found
    __args__['name'] = name
    __args__['tags'] = tags
    __args__['type'] = type
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getEntity:getEntity', __args__, opts=opts, typ=GetEntityResult)
    return __ret__.apply(lambda __response__: GetEntityResult(
        account_id=pulumi.get(__response__, 'account_id'),
        application_id=pulumi.get(__response__, 'application_id'),
        domain=pulumi.get(__response__, 'domain'),
        entity_tags=pulumi.get(__response__, 'entity_tags'),
        guid=pulumi.get(__response__, 'guid'),
        id=pulumi.get(__response__, 'id'),
        ignore_case=pulumi.get(__response__, 'ignore_case'),
        ignore_not_found=pulumi.get(__response__, 'ignore_not_found'),
        name=pulumi.get(__response__, 'name'),
        serving_apm_application_id=pulumi.get(__response__, 'serving_apm_application_id'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['WorkloadArgs', 'Workload']

@pulumi.input_type
class WorkloadArgs:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 entity_guids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 entity_search_queries: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scope_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status_config_automatic: Optional[pulumi.Input['WorkloadStatusConfigAutomaticArgs']] = None,
                 status_config_static: Optional[pulumi.Input['WorkloadStatusConfigStaticArgs']] = None):
        """
        The set of arguments for constructing a Workload resource.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID where you want to create the workload.
        :param pulumi.Input[builtins.str] description: Relevant information about the workload.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] entity_guids: A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        :param pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]] entity_search_queries: A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        :param pulumi.Input[builtins.str] name: The workload's name.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scope_account_ids: A list of account IDs that will be used to get entities from.
        :param pulumi.Input['WorkloadStatusConfigAutomaticArgs'] status_config_automatic: An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        :param pulumi.Input['WorkloadStatusConfigStaticArgs'] status_config_static: A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entity_guids is not None:
            pulumi.set(__self__, "entity_guids", entity_guids)
        if entity_search_queries is not None:
            pulumi.set(__self__, "entity_search_queries", entity_search_queries)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if scope_account_ids is not None:
            pulumi.set(__self__, "scope_account_ids", scope_account_ids)
        if status_config_automatic is not None:
            pulumi.set(__self__, "status_config_automatic", status_config_automatic)
        if status_config_static is not None:
            pulumi.set(__self__, "status_config_static", status_config_static)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The New Relic account ID where you want to create the workload.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Relevant information about the workload.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="entityGuids")
    def entity_guids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        """
        return pulumi.get(self, "entity_guids")

    @entity_guids.setter
    def entity_guids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "entity_guids", value)

    @property
    @pulumi.getter(name="entitySearchQueries")
    def entity_search_queries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]]]:
        """
        A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        """
        return pulumi.get(self, "entity_search_queries")

    @entity_search_queries.setter
    def entity_search_queries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]]]):
        pulumi.set(self, "entity_search_queries", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The workload's name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="scopeAccountIds")
    def scope_account_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of account IDs that will be used to get entities from.
        """
        return pulumi.get(self, "scope_account_ids")

    @scope_account_ids.setter
    def scope_account_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "scope_account_ids", value)

    @property
    @pulumi.getter(name="statusConfigAutomatic")
    def status_config_automatic(self) -> Optional[pulumi.Input['WorkloadStatusConfigAutomaticArgs']]:
        """
        An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        """
        return pulumi.get(self, "status_config_automatic")

    @status_config_automatic.setter
    def status_config_automatic(self, value: Optional[pulumi.Input['WorkloadStatusConfigAutomaticArgs']]):
        pulumi.set(self, "status_config_automatic", value)

    @property
    @pulumi.getter(name="statusConfigStatic")
    def status_config_static(self) -> Optional[pulumi.Input['WorkloadStatusConfigStaticArgs']]:
        """
        A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        """
        return pulumi.get(self, "status_config_static")

    @status_config_static.setter
    def status_config_static(self, value: Optional[pulumi.Input['WorkloadStatusConfigStaticArgs']]):
        pulumi.set(self, "status_config_static", value)


@pulumi.input_type
class _WorkloadState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 composite_entity_search_query: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 entity_guids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 entity_search_queries: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]]] = None,
                 guid: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permalink: Optional[pulumi.Input[builtins.str]] = None,
                 scope_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status_config_automatic: Optional[pulumi.Input['WorkloadStatusConfigAutomaticArgs']] = None,
                 status_config_static: Optional[pulumi.Input['WorkloadStatusConfigStaticArgs']] = None,
                 workload_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Workload resources.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID where you want to create the workload.
        :param pulumi.Input[builtins.str] composite_entity_search_query: The composite query used to compose a dynamic workload.
        :param pulumi.Input[builtins.str] description: Relevant information about the workload.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] entity_guids: A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        :param pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]] entity_search_queries: A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        :param pulumi.Input[builtins.str] guid: The unique entity identifier of the workload in New Relic.
        :param pulumi.Input[builtins.str] name: The workload's name.
        :param pulumi.Input[builtins.str] permalink: The URL of the workload.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scope_account_ids: A list of account IDs that will be used to get entities from.
        :param pulumi.Input['WorkloadStatusConfigAutomaticArgs'] status_config_automatic: An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        :param pulumi.Input['WorkloadStatusConfigStaticArgs'] status_config_static: A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        :param pulumi.Input[builtins.str] workload_id: The unique entity identifier of the workload.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if composite_entity_search_query is not None:
            pulumi.set(__self__, "composite_entity_search_query", composite_entity_search_query)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if entity_guids is not None:
            pulumi.set(__self__, "entity_guids", entity_guids)
        if entity_search_queries is not None:
            pulumi.set(__self__, "entity_search_queries", entity_search_queries)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permalink is not None:
            pulumi.set(__self__, "permalink", permalink)
        if scope_account_ids is not None:
            pulumi.set(__self__, "scope_account_ids", scope_account_ids)
        if status_config_automatic is not None:
            pulumi.set(__self__, "status_config_automatic", status_config_automatic)
        if status_config_static is not None:
            pulumi.set(__self__, "status_config_static", status_config_static)
        if workload_id is not None:
            pulumi.set(__self__, "workload_id", workload_id)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The New Relic account ID where you want to create the workload.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="compositeEntitySearchQuery")
    def composite_entity_search_query(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The composite query used to compose a dynamic workload.
        """
        return pulumi.get(self, "composite_entity_search_query")

    @composite_entity_search_query.setter
    def composite_entity_search_query(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "composite_entity_search_query", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Relevant information about the workload.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="entityGuids")
    def entity_guids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        """
        return pulumi.get(self, "entity_guids")

    @entity_guids.setter
    def entity_guids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "entity_guids", value)

    @property
    @pulumi.getter(name="entitySearchQueries")
    def entity_search_queries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]]]:
        """
        A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        """
        return pulumi.get(self, "entity_search_queries")

    @entity_search_queries.setter
    def entity_search_queries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['WorkloadEntitySearchQueryArgs']]]]):
        pulumi.set(self, "entity_search_queries", value)

    @property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unique entity identifier of the workload in New Relic.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "guid", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The workload's name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def permalink(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The URL of the workload.
        """
        return pulumi.get(self, "permalink")

    @permalink.setter
    def permalink(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permalink", value)

    @property
    @pulumi.getter(name="scopeAccountIds")
    def scope_account_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        A list of account IDs that will be used to get entities from.
        """
        return pulumi.get(self, "scope_account_ids")

    @scope_account_ids.setter
    def scope_account_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "scope_account_ids", value)

    @property
    @pulumi.getter(name="statusConfigAutomatic")
    def status_config_automatic(self) -> Optional[pulumi.Input['WorkloadStatusConfigAutomaticArgs']]:
        """
        An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        """
        return pulumi.get(self, "status_config_automatic")

    @status_config_automatic.setter
    def status_config_automatic(self, value: Optional[pulumi.Input['WorkloadStatusConfigAutomaticArgs']]):
        pulumi.set(self, "status_config_automatic", value)

    @property
    @pulumi.getter(name="statusConfigStatic")
    def status_config_static(self) -> Optional[pulumi.Input['WorkloadStatusConfigStaticArgs']]:
        """
        A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        """
        return pulumi.get(self, "status_config_static")

    @status_config_static.setter
    def status_config_static(self, value: Optional[pulumi.Input['WorkloadStatusConfigStaticArgs']]):
        pulumi.set(self, "status_config_static", value)

    @property
    @pulumi.getter(name="workloadId")
    def workload_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The unique entity identifier of the workload.
        """
        return pulumi.get(self, "workload_id")

    @workload_id.setter
    def workload_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "workload_id", value)


class Workload(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 entity_guids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 entity_search_queries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkloadEntitySearchQueryArgs', 'WorkloadEntitySearchQueryArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scope_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status_config_automatic: Optional[pulumi.Input[Union['WorkloadStatusConfigAutomaticArgs', 'WorkloadStatusConfigAutomaticArgsDict']]] = None,
                 status_config_static: Optional[pulumi.Input[Union['WorkloadStatusConfigStaticArgs', 'WorkloadStatusConfigStaticArgsDict']]] = None,
                 __props__=None):
        """
        Use this resource to create, update, and delete a New Relic One workload.

        A New Relic User API key is required to provision this resource.  Set the `api_key`
        attribute in the `provider` block or the `NEW_RELIC_API_KEY` environment
        variable with your User API key.

        ## Example Usage

        Include entities with a certain string on the name.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "name like '%Example application%'",
            }],
            scope_account_ids=["12345678"])
        ```

        Include entities with a set of tags.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload with tags",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "tags.accountId = '12345678' AND tags.environment='production' AND tags.language='java'",
            }],
            scope_account_ids=["12345678"])
        ```

        Include entities with a set of tags.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload with tags",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "tags.accountId = '12345678' AND tags.environment='production' AND tags.language='java'",
            }],
            scope_account_ids=["12345678"])
        ```

        Include automatic status

        > The global status of your workload is a quick indicator of the workload health. You can configure it to be calculated automatically, and you can also set an alert and get a notification whenever the workload stops being operational. Alternatively, you can communicate a certain status of the workload by setting up a static value and a description. [See our docs](https://docs.newrelic.com/docs/workloads/use-workloads/workloads/workload-status)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "name like '%Example application%'",
            }],
            scope_account_ids=["12345678"],
            description="Description",
            status_config_automatic={
                "enabled": True,
                "remaining_entities_rule": {
                    "remaining_entities_rule_rollup": {
                        "strategy": "BEST_STATUS_WINS",
                        "threshold_type": "FIXED",
                        "threshold_value": 100,
                        "group_by": "ENTITY_TYPE",
                    },
                },
                "rules": [{
                    "entity_guids": ["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
                    "nrql_queries": [{
                        "query": "name like '%Example application2%'",
                    }],
                    "rollup": {
                        "strategy": "BEST_STATUS_WINS",
                        "threshold_type": "FIXED",
                        "threshold_value": 100,
                    },
                }],
            })
        ```

        Include static status

        > You can use this during maintenance tasks or any other time you want to provide a fixed status for your workload. This overrides all automatic rules. [See our docs](https://docs.newrelic.com/docs/workloads/use-workloads/workloads/workload-status#configure-static)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "name like '%Example application%'",
            }],
            scope_account_ids=["12345678"],
            description="Description",
            status_config_static={
                "description": "test",
                "enabled": True,
                "status": "OPERATIONAL",
                "summary": "summary of the status",
            })
        ```

        ## Import

        New Relic workloads can be imported using a concatenated string of the format

         `<account_id>:<workload_id>:<guid>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:plugins/workload:Workload foo 12345678:1456:MjUyMDUyOHxBUE18QVBRTElDQVRJT058MjE1MDM3Nzk1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID where you want to create the workload.
        :param pulumi.Input[builtins.str] description: Relevant information about the workload.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] entity_guids: A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkloadEntitySearchQueryArgs', 'WorkloadEntitySearchQueryArgsDict']]]] entity_search_queries: A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        :param pulumi.Input[builtins.str] name: The workload's name.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scope_account_ids: A list of account IDs that will be used to get entities from.
        :param pulumi.Input[Union['WorkloadStatusConfigAutomaticArgs', 'WorkloadStatusConfigAutomaticArgsDict']] status_config_automatic: An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        :param pulumi.Input[Union['WorkloadStatusConfigStaticArgs', 'WorkloadStatusConfigStaticArgsDict']] status_config_static: A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[WorkloadArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update, and delete a New Relic One workload.

        A New Relic User API key is required to provision this resource.  Set the `api_key`
        attribute in the `provider` block or the `NEW_RELIC_API_KEY` environment
        variable with your User API key.

        ## Example Usage

        Include entities with a certain string on the name.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "name like '%Example application%'",
            }],
            scope_account_ids=["12345678"])
        ```

        Include entities with a set of tags.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload with tags",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "tags.accountId = '12345678' AND tags.environment='production' AND tags.language='java'",
            }],
            scope_account_ids=["12345678"])
        ```

        Include entities with a set of tags.
        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload with tags",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "tags.accountId = '12345678' AND tags.environment='production' AND tags.language='java'",
            }],
            scope_account_ids=["12345678"])
        ```

        Include automatic status

        > The global status of your workload is a quick indicator of the workload health. You can configure it to be calculated automatically, and you can also set an alert and get a notification whenever the workload stops being operational. Alternatively, you can communicate a certain status of the workload by setting up a static value and a description. [See our docs](https://docs.newrelic.com/docs/workloads/use-workloads/workloads/workload-status)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "name like '%Example application%'",
            }],
            scope_account_ids=["12345678"],
            description="Description",
            status_config_automatic={
                "enabled": True,
                "remaining_entities_rule": {
                    "remaining_entities_rule_rollup": {
                        "strategy": "BEST_STATUS_WINS",
                        "threshold_type": "FIXED",
                        "threshold_value": 100,
                        "group_by": "ENTITY_TYPE",
                    },
                },
                "rules": [{
                    "entity_guids": ["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
                    "nrql_queries": [{
                        "query": "name like '%Example application2%'",
                    }],
                    "rollup": {
                        "strategy": "BEST_STATUS_WINS",
                        "threshold_type": "FIXED",
                        "threshold_value": 100,
                    },
                }],
            })
        ```

        Include static status

        > You can use this during maintenance tasks or any other time you want to provide a fixed status for your workload. This overrides all automatic rules. [See our docs](https://docs.newrelic.com/docs/workloads/use-workloads/workloads/workload-status#configure-static)

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.plugins.Workload("foo",
            name="Example workload",
            account_id="12345678",
            entity_guids=["MjUyMDUyOHxBUE18QVBQTElDQVRJT058MjE1MDM3Nzk1"],
            entity_search_queries=[{
                "query": "name like '%Example application%'",
            }],
            scope_account_ids=["12345678"],
            description="Description",
            status_config_static={
                "description": "test",
                "enabled": True,
                "status": "OPERATIONAL",
                "summary": "summary of the status",
            })
        ```

        ## Import

        New Relic workloads can be imported using a concatenated string of the format

         `<account_id>:<workload_id>:<guid>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:plugins/workload:Workload foo 12345678:1456:MjUyMDUyOHxBUE18QVBRTElDQVRJT058MjE1MDM3Nzk1
        ```

        :param str resource_name: The name of the resource.
        :param WorkloadArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(WorkloadArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 entity_guids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 entity_search_queries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkloadEntitySearchQueryArgs', 'WorkloadEntitySearchQueryArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 scope_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status_config_automatic: Optional[pulumi.Input[Union['WorkloadStatusConfigAutomaticArgs', 'WorkloadStatusConfigAutomaticArgsDict']]] = None,
                 status_config_static: Optional[pulumi.Input[Union['WorkloadStatusConfigStaticArgs', 'WorkloadStatusConfigStaticArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = WorkloadArgs.__new__(WorkloadArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["description"] = description
            __props__.__dict__["entity_guids"] = entity_guids
            __props__.__dict__["entity_search_queries"] = entity_search_queries
            __props__.__dict__["name"] = name
            __props__.__dict__["scope_account_ids"] = scope_account_ids
            __props__.__dict__["status_config_automatic"] = status_config_automatic
            __props__.__dict__["status_config_static"] = status_config_static
            __props__.__dict__["composite_entity_search_query"] = None
            __props__.__dict__["guid"] = None
            __props__.__dict__["permalink"] = None
            __props__.__dict__["workload_id"] = None
        super(Workload, __self__).__init__(
            'newrelic:plugins/workload:Workload',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            composite_entity_search_query: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            entity_guids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            entity_search_queries: Optional[pulumi.Input[Sequence[pulumi.Input[Union['WorkloadEntitySearchQueryArgs', 'WorkloadEntitySearchQueryArgsDict']]]]] = None,
            guid: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            permalink: Optional[pulumi.Input[builtins.str]] = None,
            scope_account_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            status_config_automatic: Optional[pulumi.Input[Union['WorkloadStatusConfigAutomaticArgs', 'WorkloadStatusConfigAutomaticArgsDict']]] = None,
            status_config_static: Optional[pulumi.Input[Union['WorkloadStatusConfigStaticArgs', 'WorkloadStatusConfigStaticArgsDict']]] = None,
            workload_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Workload':
        """
        Get an existing Workload resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID where you want to create the workload.
        :param pulumi.Input[builtins.str] composite_entity_search_query: The composite query used to compose a dynamic workload.
        :param pulumi.Input[builtins.str] description: Relevant information about the workload.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] entity_guids: A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        :param pulumi.Input[Sequence[pulumi.Input[Union['WorkloadEntitySearchQueryArgs', 'WorkloadEntitySearchQueryArgsDict']]]] entity_search_queries: A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        :param pulumi.Input[builtins.str] guid: The unique entity identifier of the workload in New Relic.
        :param pulumi.Input[builtins.str] name: The workload's name.
        :param pulumi.Input[builtins.str] permalink: The URL of the workload.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] scope_account_ids: A list of account IDs that will be used to get entities from.
        :param pulumi.Input[Union['WorkloadStatusConfigAutomaticArgs', 'WorkloadStatusConfigAutomaticArgsDict']] status_config_automatic: An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        :param pulumi.Input[Union['WorkloadStatusConfigStaticArgs', 'WorkloadStatusConfigStaticArgsDict']] status_config_static: A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        :param pulumi.Input[builtins.str] workload_id: The unique entity identifier of the workload.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _WorkloadState.__new__(_WorkloadState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["composite_entity_search_query"] = composite_entity_search_query
        __props__.__dict__["description"] = description
        __props__.__dict__["entity_guids"] = entity_guids
        __props__.__dict__["entity_search_queries"] = entity_search_queries
        __props__.__dict__["guid"] = guid
        __props__.__dict__["name"] = name
        __props__.__dict__["permalink"] = permalink
        __props__.__dict__["scope_account_ids"] = scope_account_ids
        __props__.__dict__["status_config_automatic"] = status_config_automatic
        __props__.__dict__["status_config_static"] = status_config_static
        __props__.__dict__["workload_id"] = workload_id
        return Workload(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        The New Relic account ID where you want to create the workload.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="compositeEntitySearchQuery")
    def composite_entity_search_query(self) -> pulumi.Output[builtins.str]:
        """
        The composite query used to compose a dynamic workload.
        """
        return pulumi.get(self, "composite_entity_search_query")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Relevant information about the workload.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="entityGuids")
    def entity_guids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        A list of entity GUIDs manually assigned to this workload. At least one of either `entity_guids` or `entity_search_query` is required.
        """
        return pulumi.get(self, "entity_guids")

    @property
    @pulumi.getter(name="entitySearchQueries")
    def entity_search_queries(self) -> pulumi.Output[Optional[Sequence['outputs.WorkloadEntitySearchQuery']]]:
        """
        A list of search queries that define a dynamic workload. At least one of either `entity_guids` or `entity_search_query` is required. See Nested entity_search_query blocks below for details.
        """
        return pulumi.get(self, "entity_search_queries")

    @property
    @pulumi.getter
    def guid(self) -> pulumi.Output[builtins.str]:
        """
        The unique entity identifier of the workload in New Relic.
        """
        return pulumi.get(self, "guid")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The workload's name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def permalink(self) -> pulumi.Output[builtins.str]:
        """
        The URL of the workload.
        """
        return pulumi.get(self, "permalink")

    @property
    @pulumi.getter(name="scopeAccountIds")
    def scope_account_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        A list of account IDs that will be used to get entities from.
        """
        return pulumi.get(self, "scope_account_ids")

    @property
    @pulumi.getter(name="statusConfigAutomatic")
    def status_config_automatic(self) -> pulumi.Output[Optional['outputs.WorkloadStatusConfigAutomatic']]:
        """
        An input object used to represent an automatic status configuration.See Nested status_config_automatic blocks below for details.
        """
        return pulumi.get(self, "status_config_automatic")

    @property
    @pulumi.getter(name="statusConfigStatic")
    def status_config_static(self) -> pulumi.Output[Optional['outputs.WorkloadStatusConfigStatic']]:
        """
        A list of static status configurations. You can only configure one static status for a workload.See Nested status_config_static blocks below for details.
        """
        return pulumi.get(self, "status_config_static")

    @property
    @pulumi.getter(name="workloadId")
    def workload_id(self) -> pulumi.Output[builtins.str]:
        """
        The unique entity identifier of the workload.
        """
        return pulumi.get(self, "workload_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GcpIntegrationsArgs', 'GcpIntegrations']

@pulumi.input_type
class GcpIntegrationsArgs:
    def __init__(__self__, *,
                 linked_account_id: pulumi.Input[builtins.str],
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 alloy_db: Optional[pulumi.Input['GcpIntegrationsAlloyDbArgs']] = None,
                 app_engine: Optional[pulumi.Input['GcpIntegrationsAppEngineArgs']] = None,
                 big_query: Optional[pulumi.Input['GcpIntegrationsBigQueryArgs']] = None,
                 big_table: Optional[pulumi.Input['GcpIntegrationsBigTableArgs']] = None,
                 composer: Optional[pulumi.Input['GcpIntegrationsComposerArgs']] = None,
                 data_flow: Optional[pulumi.Input['GcpIntegrationsDataFlowArgs']] = None,
                 data_proc: Optional[pulumi.Input['GcpIntegrationsDataProcArgs']] = None,
                 data_store: Optional[pulumi.Input['GcpIntegrationsDataStoreArgs']] = None,
                 fire_base_database: Optional[pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs']] = None,
                 fire_base_hosting: Optional[pulumi.Input['GcpIntegrationsFireBaseHostingArgs']] = None,
                 fire_base_storage: Optional[pulumi.Input['GcpIntegrationsFireBaseStorageArgs']] = None,
                 fire_store: Optional[pulumi.Input['GcpIntegrationsFireStoreArgs']] = None,
                 functions: Optional[pulumi.Input['GcpIntegrationsFunctionsArgs']] = None,
                 interconnect: Optional[pulumi.Input['GcpIntegrationsInterconnectArgs']] = None,
                 kubernetes: Optional[pulumi.Input['GcpIntegrationsKubernetesArgs']] = None,
                 load_balancing: Optional[pulumi.Input['GcpIntegrationsLoadBalancingArgs']] = None,
                 mem_cache: Optional[pulumi.Input['GcpIntegrationsMemCacheArgs']] = None,
                 pub_sub: Optional[pulumi.Input['GcpIntegrationsPubSubArgs']] = None,
                 redis: Optional[pulumi.Input['GcpIntegrationsRedisArgs']] = None,
                 router: Optional[pulumi.Input['GcpIntegrationsRouterArgs']] = None,
                 run: Optional[pulumi.Input['GcpIntegrationsRunArgs']] = None,
                 spanner: Optional[pulumi.Input['GcpIntegrationsSpannerArgs']] = None,
                 sql: Optional[pulumi.Input['GcpIntegrationsSqlArgs']] = None,
                 storage: Optional[pulumi.Input['GcpIntegrationsStorageArgs']] = None,
                 virtual_machines: Optional[pulumi.Input['GcpIntegrationsVirtualMachinesArgs']] = None,
                 vpc_access: Optional[pulumi.Input['GcpIntegrationsVpcAccessArgs']] = None):
        """
        The set of arguments for constructing a GcpIntegrations resource.
        :param pulumi.Input[builtins.str] linked_account_id: The ID of the linked GCP account in New Relic.
               
               The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input['GcpIntegrationsAlloyDbArgs'] alloy_db: Alloy DB integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsAppEngineArgs'] app_engine: App Engine integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsBigQueryArgs'] big_query: Biq Query integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsBigTableArgs'] big_table: Big Table. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsComposerArgs'] composer: Composer integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsDataFlowArgs'] data_flow: Data Flow integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsDataProcArgs'] data_proc: Data Proc integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsDataStoreArgs'] data_store: Data Store integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs'] fire_base_database: Fire Base Database integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireBaseHostingArgs'] fire_base_hosting: Fire Base Hosting integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireBaseStorageArgs'] fire_base_storage: Fire Base Storage integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireStoreArgs'] fire_store: Fire Store integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFunctionsArgs'] functions: Functions integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsInterconnectArgs'] interconnect: Interconnect integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsKubernetesArgs'] kubernetes: Kubernetes integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsLoadBalancingArgs'] load_balancing: Load Balancing integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsMemCacheArgs'] mem_cache: Mem cache integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsPubSubArgs'] pub_sub: Pub/Sub integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsRedisArgs'] redis: Redis integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsRouterArgs'] router: Router integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsRunArgs'] run: Run integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsSpannerArgs'] spanner: Spanner integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsSqlArgs'] sql: SQL integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsStorageArgs'] storage: Storage integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsVirtualMachinesArgs'] virtual_machines: Virtual machines integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsVpcAccessArgs'] vpc_access: VPC Access integration. See Integration blocks below for details.
        """
        pulumi.set(__self__, "linked_account_id", linked_account_id)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if alloy_db is not None:
            pulumi.set(__self__, "alloy_db", alloy_db)
        if app_engine is not None:
            pulumi.set(__self__, "app_engine", app_engine)
        if big_query is not None:
            pulumi.set(__self__, "big_query", big_query)
        if big_table is not None:
            pulumi.set(__self__, "big_table", big_table)
        if composer is not None:
            pulumi.set(__self__, "composer", composer)
        if data_flow is not None:
            pulumi.set(__self__, "data_flow", data_flow)
        if data_proc is not None:
            pulumi.set(__self__, "data_proc", data_proc)
        if data_store is not None:
            pulumi.set(__self__, "data_store", data_store)
        if fire_base_database is not None:
            pulumi.set(__self__, "fire_base_database", fire_base_database)
        if fire_base_hosting is not None:
            pulumi.set(__self__, "fire_base_hosting", fire_base_hosting)
        if fire_base_storage is not None:
            pulumi.set(__self__, "fire_base_storage", fire_base_storage)
        if fire_store is not None:
            pulumi.set(__self__, "fire_store", fire_store)
        if functions is not None:
            pulumi.set(__self__, "functions", functions)
        if interconnect is not None:
            pulumi.set(__self__, "interconnect", interconnect)
        if kubernetes is not None:
            pulumi.set(__self__, "kubernetes", kubernetes)
        if load_balancing is not None:
            pulumi.set(__self__, "load_balancing", load_balancing)
        if mem_cache is not None:
            pulumi.set(__self__, "mem_cache", mem_cache)
        if pub_sub is not None:
            pulumi.set(__self__, "pub_sub", pub_sub)
        if redis is not None:
            pulumi.set(__self__, "redis", redis)
        if router is not None:
            pulumi.set(__self__, "router", router)
        if run is not None:
            pulumi.set(__self__, "run", run)
        if spanner is not None:
            pulumi.set(__self__, "spanner", spanner)
        if sql is not None:
            pulumi.set(__self__, "sql", sql)
        if storage is not None:
            pulumi.set(__self__, "storage", storage)
        if virtual_machines is not None:
            pulumi.set(__self__, "virtual_machines", virtual_machines)
        if vpc_access is not None:
            pulumi.set(__self__, "vpc_access", vpc_access)

    @property
    @pulumi.getter(name="linkedAccountId")
    def linked_account_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the linked GCP account in New Relic.

        The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        """
        return pulumi.get(self, "linked_account_id")

    @linked_account_id.setter
    def linked_account_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "linked_account_id", value)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="alloyDb")
    def alloy_db(self) -> Optional[pulumi.Input['GcpIntegrationsAlloyDbArgs']]:
        """
        Alloy DB integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "alloy_db")

    @alloy_db.setter
    def alloy_db(self, value: Optional[pulumi.Input['GcpIntegrationsAlloyDbArgs']]):
        pulumi.set(self, "alloy_db", value)

    @property
    @pulumi.getter(name="appEngine")
    def app_engine(self) -> Optional[pulumi.Input['GcpIntegrationsAppEngineArgs']]:
        """
        App Engine integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "app_engine")

    @app_engine.setter
    def app_engine(self, value: Optional[pulumi.Input['GcpIntegrationsAppEngineArgs']]):
        pulumi.set(self, "app_engine", value)

    @property
    @pulumi.getter(name="bigQuery")
    def big_query(self) -> Optional[pulumi.Input['GcpIntegrationsBigQueryArgs']]:
        """
        Biq Query integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "big_query")

    @big_query.setter
    def big_query(self, value: Optional[pulumi.Input['GcpIntegrationsBigQueryArgs']]):
        pulumi.set(self, "big_query", value)

    @property
    @pulumi.getter(name="bigTable")
    def big_table(self) -> Optional[pulumi.Input['GcpIntegrationsBigTableArgs']]:
        """
        Big Table. See Integration blocks below for details.
        """
        return pulumi.get(self, "big_table")

    @big_table.setter
    def big_table(self, value: Optional[pulumi.Input['GcpIntegrationsBigTableArgs']]):
        pulumi.set(self, "big_table", value)

    @property
    @pulumi.getter
    def composer(self) -> Optional[pulumi.Input['GcpIntegrationsComposerArgs']]:
        """
        Composer integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "composer")

    @composer.setter
    def composer(self, value: Optional[pulumi.Input['GcpIntegrationsComposerArgs']]):
        pulumi.set(self, "composer", value)

    @property
    @pulumi.getter(name="dataFlow")
    def data_flow(self) -> Optional[pulumi.Input['GcpIntegrationsDataFlowArgs']]:
        """
        Data Flow integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_flow")

    @data_flow.setter
    def data_flow(self, value: Optional[pulumi.Input['GcpIntegrationsDataFlowArgs']]):
        pulumi.set(self, "data_flow", value)

    @property
    @pulumi.getter(name="dataProc")
    def data_proc(self) -> Optional[pulumi.Input['GcpIntegrationsDataProcArgs']]:
        """
        Data Proc integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_proc")

    @data_proc.setter
    def data_proc(self, value: Optional[pulumi.Input['GcpIntegrationsDataProcArgs']]):
        pulumi.set(self, "data_proc", value)

    @property
    @pulumi.getter(name="dataStore")
    def data_store(self) -> Optional[pulumi.Input['GcpIntegrationsDataStoreArgs']]:
        """
        Data Store integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_store")

    @data_store.setter
    def data_store(self, value: Optional[pulumi.Input['GcpIntegrationsDataStoreArgs']]):
        pulumi.set(self, "data_store", value)

    @property
    @pulumi.getter(name="fireBaseDatabase")
    def fire_base_database(self) -> Optional[pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs']]:
        """
        Fire Base Database integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_database")

    @fire_base_database.setter
    def fire_base_database(self, value: Optional[pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs']]):
        pulumi.set(self, "fire_base_database", value)

    @property
    @pulumi.getter(name="fireBaseHosting")
    def fire_base_hosting(self) -> Optional[pulumi.Input['GcpIntegrationsFireBaseHostingArgs']]:
        """
        Fire Base Hosting integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_hosting")

    @fire_base_hosting.setter
    def fire_base_hosting(self, value: Optional[pulumi.Input['GcpIntegrationsFireBaseHostingArgs']]):
        pulumi.set(self, "fire_base_hosting", value)

    @property
    @pulumi.getter(name="fireBaseStorage")
    def fire_base_storage(self) -> Optional[pulumi.Input['GcpIntegrationsFireBaseStorageArgs']]:
        """
        Fire Base Storage integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_storage")

    @fire_base_storage.setter
    def fire_base_storage(self, value: Optional[pulumi.Input['GcpIntegrationsFireBaseStorageArgs']]):
        pulumi.set(self, "fire_base_storage", value)

    @property
    @pulumi.getter(name="fireStore")
    def fire_store(self) -> Optional[pulumi.Input['GcpIntegrationsFireStoreArgs']]:
        """
        Fire Store integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_store")

    @fire_store.setter
    def fire_store(self, value: Optional[pulumi.Input['GcpIntegrationsFireStoreArgs']]):
        pulumi.set(self, "fire_store", value)

    @property
    @pulumi.getter
    def functions(self) -> Optional[pulumi.Input['GcpIntegrationsFunctionsArgs']]:
        """
        Functions integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "functions")

    @functions.setter
    def functions(self, value: Optional[pulumi.Input['GcpIntegrationsFunctionsArgs']]):
        pulumi.set(self, "functions", value)

    @property
    @pulumi.getter
    def interconnect(self) -> Optional[pulumi.Input['GcpIntegrationsInterconnectArgs']]:
        """
        Interconnect integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "interconnect")

    @interconnect.setter
    def interconnect(self, value: Optional[pulumi.Input['GcpIntegrationsInterconnectArgs']]):
        pulumi.set(self, "interconnect", value)

    @property
    @pulumi.getter
    def kubernetes(self) -> Optional[pulumi.Input['GcpIntegrationsKubernetesArgs']]:
        """
        Kubernetes integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "kubernetes")

    @kubernetes.setter
    def kubernetes(self, value: Optional[pulumi.Input['GcpIntegrationsKubernetesArgs']]):
        pulumi.set(self, "kubernetes", value)

    @property
    @pulumi.getter(name="loadBalancing")
    def load_balancing(self) -> Optional[pulumi.Input['GcpIntegrationsLoadBalancingArgs']]:
        """
        Load Balancing integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "load_balancing")

    @load_balancing.setter
    def load_balancing(self, value: Optional[pulumi.Input['GcpIntegrationsLoadBalancingArgs']]):
        pulumi.set(self, "load_balancing", value)

    @property
    @pulumi.getter(name="memCache")
    def mem_cache(self) -> Optional[pulumi.Input['GcpIntegrationsMemCacheArgs']]:
        """
        Mem cache integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "mem_cache")

    @mem_cache.setter
    def mem_cache(self, value: Optional[pulumi.Input['GcpIntegrationsMemCacheArgs']]):
        pulumi.set(self, "mem_cache", value)

    @property
    @pulumi.getter(name="pubSub")
    def pub_sub(self) -> Optional[pulumi.Input['GcpIntegrationsPubSubArgs']]:
        """
        Pub/Sub integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "pub_sub")

    @pub_sub.setter
    def pub_sub(self, value: Optional[pulumi.Input['GcpIntegrationsPubSubArgs']]):
        pulumi.set(self, "pub_sub", value)

    @property
    @pulumi.getter
    def redis(self) -> Optional[pulumi.Input['GcpIntegrationsRedisArgs']]:
        """
        Redis integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "redis")

    @redis.setter
    def redis(self, value: Optional[pulumi.Input['GcpIntegrationsRedisArgs']]):
        pulumi.set(self, "redis", value)

    @property
    @pulumi.getter
    def router(self) -> Optional[pulumi.Input['GcpIntegrationsRouterArgs']]:
        """
        Router integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "router")

    @router.setter
    def router(self, value: Optional[pulumi.Input['GcpIntegrationsRouterArgs']]):
        pulumi.set(self, "router", value)

    @property
    @pulumi.getter
    def run(self) -> Optional[pulumi.Input['GcpIntegrationsRunArgs']]:
        """
        Run integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "run")

    @run.setter
    def run(self, value: Optional[pulumi.Input['GcpIntegrationsRunArgs']]):
        pulumi.set(self, "run", value)

    @property
    @pulumi.getter
    def spanner(self) -> Optional[pulumi.Input['GcpIntegrationsSpannerArgs']]:
        """
        Spanner integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "spanner")

    @spanner.setter
    def spanner(self, value: Optional[pulumi.Input['GcpIntegrationsSpannerArgs']]):
        pulumi.set(self, "spanner", value)

    @property
    @pulumi.getter
    def sql(self) -> Optional[pulumi.Input['GcpIntegrationsSqlArgs']]:
        """
        SQL integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "sql")

    @sql.setter
    def sql(self, value: Optional[pulumi.Input['GcpIntegrationsSqlArgs']]):
        pulumi.set(self, "sql", value)

    @property
    @pulumi.getter
    def storage(self) -> Optional[pulumi.Input['GcpIntegrationsStorageArgs']]:
        """
        Storage integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "storage")

    @storage.setter
    def storage(self, value: Optional[pulumi.Input['GcpIntegrationsStorageArgs']]):
        pulumi.set(self, "storage", value)

    @property
    @pulumi.getter(name="virtualMachines")
    def virtual_machines(self) -> Optional[pulumi.Input['GcpIntegrationsVirtualMachinesArgs']]:
        """
        Virtual machines integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "virtual_machines")

    @virtual_machines.setter
    def virtual_machines(self, value: Optional[pulumi.Input['GcpIntegrationsVirtualMachinesArgs']]):
        pulumi.set(self, "virtual_machines", value)

    @property
    @pulumi.getter(name="vpcAccess")
    def vpc_access(self) -> Optional[pulumi.Input['GcpIntegrationsVpcAccessArgs']]:
        """
        VPC Access integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "vpc_access")

    @vpc_access.setter
    def vpc_access(self, value: Optional[pulumi.Input['GcpIntegrationsVpcAccessArgs']]):
        pulumi.set(self, "vpc_access", value)


@pulumi.input_type
class _GcpIntegrationsState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 alloy_db: Optional[pulumi.Input['GcpIntegrationsAlloyDbArgs']] = None,
                 app_engine: Optional[pulumi.Input['GcpIntegrationsAppEngineArgs']] = None,
                 big_query: Optional[pulumi.Input['GcpIntegrationsBigQueryArgs']] = None,
                 big_table: Optional[pulumi.Input['GcpIntegrationsBigTableArgs']] = None,
                 composer: Optional[pulumi.Input['GcpIntegrationsComposerArgs']] = None,
                 data_flow: Optional[pulumi.Input['GcpIntegrationsDataFlowArgs']] = None,
                 data_proc: Optional[pulumi.Input['GcpIntegrationsDataProcArgs']] = None,
                 data_store: Optional[pulumi.Input['GcpIntegrationsDataStoreArgs']] = None,
                 fire_base_database: Optional[pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs']] = None,
                 fire_base_hosting: Optional[pulumi.Input['GcpIntegrationsFireBaseHostingArgs']] = None,
                 fire_base_storage: Optional[pulumi.Input['GcpIntegrationsFireBaseStorageArgs']] = None,
                 fire_store: Optional[pulumi.Input['GcpIntegrationsFireStoreArgs']] = None,
                 functions: Optional[pulumi.Input['GcpIntegrationsFunctionsArgs']] = None,
                 interconnect: Optional[pulumi.Input['GcpIntegrationsInterconnectArgs']] = None,
                 kubernetes: Optional[pulumi.Input['GcpIntegrationsKubernetesArgs']] = None,
                 linked_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancing: Optional[pulumi.Input['GcpIntegrationsLoadBalancingArgs']] = None,
                 mem_cache: Optional[pulumi.Input['GcpIntegrationsMemCacheArgs']] = None,
                 pub_sub: Optional[pulumi.Input['GcpIntegrationsPubSubArgs']] = None,
                 redis: Optional[pulumi.Input['GcpIntegrationsRedisArgs']] = None,
                 router: Optional[pulumi.Input['GcpIntegrationsRouterArgs']] = None,
                 run: Optional[pulumi.Input['GcpIntegrationsRunArgs']] = None,
                 spanner: Optional[pulumi.Input['GcpIntegrationsSpannerArgs']] = None,
                 sql: Optional[pulumi.Input['GcpIntegrationsSqlArgs']] = None,
                 storage: Optional[pulumi.Input['GcpIntegrationsStorageArgs']] = None,
                 virtual_machines: Optional[pulumi.Input['GcpIntegrationsVirtualMachinesArgs']] = None,
                 vpc_access: Optional[pulumi.Input['GcpIntegrationsVpcAccessArgs']] = None):
        """
        Input properties used for looking up and filtering GcpIntegrations resources.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input['GcpIntegrationsAlloyDbArgs'] alloy_db: Alloy DB integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsAppEngineArgs'] app_engine: App Engine integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsBigQueryArgs'] big_query: Biq Query integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsBigTableArgs'] big_table: Big Table. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsComposerArgs'] composer: Composer integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsDataFlowArgs'] data_flow: Data Flow integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsDataProcArgs'] data_proc: Data Proc integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsDataStoreArgs'] data_store: Data Store integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs'] fire_base_database: Fire Base Database integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireBaseHostingArgs'] fire_base_hosting: Fire Base Hosting integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireBaseStorageArgs'] fire_base_storage: Fire Base Storage integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFireStoreArgs'] fire_store: Fire Store integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsFunctionsArgs'] functions: Functions integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsInterconnectArgs'] interconnect: Interconnect integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsKubernetesArgs'] kubernetes: Kubernetes integration. See Integration blocks below for details.
        :param pulumi.Input[builtins.str] linked_account_id: The ID of the linked GCP account in New Relic.
               
               The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        :param pulumi.Input['GcpIntegrationsLoadBalancingArgs'] load_balancing: Load Balancing integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsMemCacheArgs'] mem_cache: Mem cache integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsPubSubArgs'] pub_sub: Pub/Sub integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsRedisArgs'] redis: Redis integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsRouterArgs'] router: Router integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsRunArgs'] run: Run integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsSpannerArgs'] spanner: Spanner integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsSqlArgs'] sql: SQL integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsStorageArgs'] storage: Storage integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsVirtualMachinesArgs'] virtual_machines: Virtual machines integration. See Integration blocks below for details.
        :param pulumi.Input['GcpIntegrationsVpcAccessArgs'] vpc_access: VPC Access integration. See Integration blocks below for details.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if alloy_db is not None:
            pulumi.set(__self__, "alloy_db", alloy_db)
        if app_engine is not None:
            pulumi.set(__self__, "app_engine", app_engine)
        if big_query is not None:
            pulumi.set(__self__, "big_query", big_query)
        if big_table is not None:
            pulumi.set(__self__, "big_table", big_table)
        if composer is not None:
            pulumi.set(__self__, "composer", composer)
        if data_flow is not None:
            pulumi.set(__self__, "data_flow", data_flow)
        if data_proc is not None:
            pulumi.set(__self__, "data_proc", data_proc)
        if data_store is not None:
            pulumi.set(__self__, "data_store", data_store)
        if fire_base_database is not None:
            pulumi.set(__self__, "fire_base_database", fire_base_database)
        if fire_base_hosting is not None:
            pulumi.set(__self__, "fire_base_hosting", fire_base_hosting)
        if fire_base_storage is not None:
            pulumi.set(__self__, "fire_base_storage", fire_base_storage)
        if fire_store is not None:
            pulumi.set(__self__, "fire_store", fire_store)
        if functions is not None:
            pulumi.set(__self__, "functions", functions)
        if interconnect is not None:
            pulumi.set(__self__, "interconnect", interconnect)
        if kubernetes is not None:
            pulumi.set(__self__, "kubernetes", kubernetes)
        if linked_account_id is not None:
            pulumi.set(__self__, "linked_account_id", linked_account_id)
        if load_balancing is not None:
            pulumi.set(__self__, "load_balancing", load_balancing)
        if mem_cache is not None:
            pulumi.set(__self__, "mem_cache", mem_cache)
        if pub_sub is not None:
            pulumi.set(__self__, "pub_sub", pub_sub)
        if redis is not None:
            pulumi.set(__self__, "redis", redis)
        if router is not None:
            pulumi.set(__self__, "router", router)
        if run is not None:
            pulumi.set(__self__, "run", run)
        if spanner is not None:
            pulumi.set(__self__, "spanner", spanner)
        if sql is not None:
            pulumi.set(__self__, "sql", sql)
        if storage is not None:
            pulumi.set(__self__, "storage", storage)
        if virtual_machines is not None:
            pulumi.set(__self__, "virtual_machines", virtual_machines)
        if vpc_access is not None:
            pulumi.set(__self__, "vpc_access", vpc_access)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_id", value)

    @property
    @pulumi.getter(name="alloyDb")
    def alloy_db(self) -> Optional[pulumi.Input['GcpIntegrationsAlloyDbArgs']]:
        """
        Alloy DB integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "alloy_db")

    @alloy_db.setter
    def alloy_db(self, value: Optional[pulumi.Input['GcpIntegrationsAlloyDbArgs']]):
        pulumi.set(self, "alloy_db", value)

    @property
    @pulumi.getter(name="appEngine")
    def app_engine(self) -> Optional[pulumi.Input['GcpIntegrationsAppEngineArgs']]:
        """
        App Engine integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "app_engine")

    @app_engine.setter
    def app_engine(self, value: Optional[pulumi.Input['GcpIntegrationsAppEngineArgs']]):
        pulumi.set(self, "app_engine", value)

    @property
    @pulumi.getter(name="bigQuery")
    def big_query(self) -> Optional[pulumi.Input['GcpIntegrationsBigQueryArgs']]:
        """
        Biq Query integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "big_query")

    @big_query.setter
    def big_query(self, value: Optional[pulumi.Input['GcpIntegrationsBigQueryArgs']]):
        pulumi.set(self, "big_query", value)

    @property
    @pulumi.getter(name="bigTable")
    def big_table(self) -> Optional[pulumi.Input['GcpIntegrationsBigTableArgs']]:
        """
        Big Table. See Integration blocks below for details.
        """
        return pulumi.get(self, "big_table")

    @big_table.setter
    def big_table(self, value: Optional[pulumi.Input['GcpIntegrationsBigTableArgs']]):
        pulumi.set(self, "big_table", value)

    @property
    @pulumi.getter
    def composer(self) -> Optional[pulumi.Input['GcpIntegrationsComposerArgs']]:
        """
        Composer integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "composer")

    @composer.setter
    def composer(self, value: Optional[pulumi.Input['GcpIntegrationsComposerArgs']]):
        pulumi.set(self, "composer", value)

    @property
    @pulumi.getter(name="dataFlow")
    def data_flow(self) -> Optional[pulumi.Input['GcpIntegrationsDataFlowArgs']]:
        """
        Data Flow integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_flow")

    @data_flow.setter
    def data_flow(self, value: Optional[pulumi.Input['GcpIntegrationsDataFlowArgs']]):
        pulumi.set(self, "data_flow", value)

    @property
    @pulumi.getter(name="dataProc")
    def data_proc(self) -> Optional[pulumi.Input['GcpIntegrationsDataProcArgs']]:
        """
        Data Proc integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_proc")

    @data_proc.setter
    def data_proc(self, value: Optional[pulumi.Input['GcpIntegrationsDataProcArgs']]):
        pulumi.set(self, "data_proc", value)

    @property
    @pulumi.getter(name="dataStore")
    def data_store(self) -> Optional[pulumi.Input['GcpIntegrationsDataStoreArgs']]:
        """
        Data Store integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_store")

    @data_store.setter
    def data_store(self, value: Optional[pulumi.Input['GcpIntegrationsDataStoreArgs']]):
        pulumi.set(self, "data_store", value)

    @property
    @pulumi.getter(name="fireBaseDatabase")
    def fire_base_database(self) -> Optional[pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs']]:
        """
        Fire Base Database integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_database")

    @fire_base_database.setter
    def fire_base_database(self, value: Optional[pulumi.Input['GcpIntegrationsFireBaseDatabaseArgs']]):
        pulumi.set(self, "fire_base_database", value)

    @property
    @pulumi.getter(name="fireBaseHosting")
    def fire_base_hosting(self) -> Optional[pulumi.Input['GcpIntegrationsFireBaseHostingArgs']]:
        """
        Fire Base Hosting integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_hosting")

    @fire_base_hosting.setter
    def fire_base_hosting(self, value: Optional[pulumi.Input['GcpIntegrationsFireBaseHostingArgs']]):
        pulumi.set(self, "fire_base_hosting", value)

    @property
    @pulumi.getter(name="fireBaseStorage")
    def fire_base_storage(self) -> Optional[pulumi.Input['GcpIntegrationsFireBaseStorageArgs']]:
        """
        Fire Base Storage integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_storage")

    @fire_base_storage.setter
    def fire_base_storage(self, value: Optional[pulumi.Input['GcpIntegrationsFireBaseStorageArgs']]):
        pulumi.set(self, "fire_base_storage", value)

    @property
    @pulumi.getter(name="fireStore")
    def fire_store(self) -> Optional[pulumi.Input['GcpIntegrationsFireStoreArgs']]:
        """
        Fire Store integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_store")

    @fire_store.setter
    def fire_store(self, value: Optional[pulumi.Input['GcpIntegrationsFireStoreArgs']]):
        pulumi.set(self, "fire_store", value)

    @property
    @pulumi.getter
    def functions(self) -> Optional[pulumi.Input['GcpIntegrationsFunctionsArgs']]:
        """
        Functions integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "functions")

    @functions.setter
    def functions(self, value: Optional[pulumi.Input['GcpIntegrationsFunctionsArgs']]):
        pulumi.set(self, "functions", value)

    @property
    @pulumi.getter
    def interconnect(self) -> Optional[pulumi.Input['GcpIntegrationsInterconnectArgs']]:
        """
        Interconnect integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "interconnect")

    @interconnect.setter
    def interconnect(self, value: Optional[pulumi.Input['GcpIntegrationsInterconnectArgs']]):
        pulumi.set(self, "interconnect", value)

    @property
    @pulumi.getter
    def kubernetes(self) -> Optional[pulumi.Input['GcpIntegrationsKubernetesArgs']]:
        """
        Kubernetes integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "kubernetes")

    @kubernetes.setter
    def kubernetes(self, value: Optional[pulumi.Input['GcpIntegrationsKubernetesArgs']]):
        pulumi.set(self, "kubernetes", value)

    @property
    @pulumi.getter(name="linkedAccountId")
    def linked_account_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the linked GCP account in New Relic.

        The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        """
        return pulumi.get(self, "linked_account_id")

    @linked_account_id.setter
    def linked_account_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "linked_account_id", value)

    @property
    @pulumi.getter(name="loadBalancing")
    def load_balancing(self) -> Optional[pulumi.Input['GcpIntegrationsLoadBalancingArgs']]:
        """
        Load Balancing integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "load_balancing")

    @load_balancing.setter
    def load_balancing(self, value: Optional[pulumi.Input['GcpIntegrationsLoadBalancingArgs']]):
        pulumi.set(self, "load_balancing", value)

    @property
    @pulumi.getter(name="memCache")
    def mem_cache(self) -> Optional[pulumi.Input['GcpIntegrationsMemCacheArgs']]:
        """
        Mem cache integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "mem_cache")

    @mem_cache.setter
    def mem_cache(self, value: Optional[pulumi.Input['GcpIntegrationsMemCacheArgs']]):
        pulumi.set(self, "mem_cache", value)

    @property
    @pulumi.getter(name="pubSub")
    def pub_sub(self) -> Optional[pulumi.Input['GcpIntegrationsPubSubArgs']]:
        """
        Pub/Sub integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "pub_sub")

    @pub_sub.setter
    def pub_sub(self, value: Optional[pulumi.Input['GcpIntegrationsPubSubArgs']]):
        pulumi.set(self, "pub_sub", value)

    @property
    @pulumi.getter
    def redis(self) -> Optional[pulumi.Input['GcpIntegrationsRedisArgs']]:
        """
        Redis integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "redis")

    @redis.setter
    def redis(self, value: Optional[pulumi.Input['GcpIntegrationsRedisArgs']]):
        pulumi.set(self, "redis", value)

    @property
    @pulumi.getter
    def router(self) -> Optional[pulumi.Input['GcpIntegrationsRouterArgs']]:
        """
        Router integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "router")

    @router.setter
    def router(self, value: Optional[pulumi.Input['GcpIntegrationsRouterArgs']]):
        pulumi.set(self, "router", value)

    @property
    @pulumi.getter
    def run(self) -> Optional[pulumi.Input['GcpIntegrationsRunArgs']]:
        """
        Run integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "run")

    @run.setter
    def run(self, value: Optional[pulumi.Input['GcpIntegrationsRunArgs']]):
        pulumi.set(self, "run", value)

    @property
    @pulumi.getter
    def spanner(self) -> Optional[pulumi.Input['GcpIntegrationsSpannerArgs']]:
        """
        Spanner integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "spanner")

    @spanner.setter
    def spanner(self, value: Optional[pulumi.Input['GcpIntegrationsSpannerArgs']]):
        pulumi.set(self, "spanner", value)

    @property
    @pulumi.getter
    def sql(self) -> Optional[pulumi.Input['GcpIntegrationsSqlArgs']]:
        """
        SQL integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "sql")

    @sql.setter
    def sql(self, value: Optional[pulumi.Input['GcpIntegrationsSqlArgs']]):
        pulumi.set(self, "sql", value)

    @property
    @pulumi.getter
    def storage(self) -> Optional[pulumi.Input['GcpIntegrationsStorageArgs']]:
        """
        Storage integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "storage")

    @storage.setter
    def storage(self, value: Optional[pulumi.Input['GcpIntegrationsStorageArgs']]):
        pulumi.set(self, "storage", value)

    @property
    @pulumi.getter(name="virtualMachines")
    def virtual_machines(self) -> Optional[pulumi.Input['GcpIntegrationsVirtualMachinesArgs']]:
        """
        Virtual machines integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "virtual_machines")

    @virtual_machines.setter
    def virtual_machines(self, value: Optional[pulumi.Input['GcpIntegrationsVirtualMachinesArgs']]):
        pulumi.set(self, "virtual_machines", value)

    @property
    @pulumi.getter(name="vpcAccess")
    def vpc_access(self) -> Optional[pulumi.Input['GcpIntegrationsVpcAccessArgs']]:
        """
        VPC Access integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "vpc_access")

    @vpc_access.setter
    def vpc_access(self, value: Optional[pulumi.Input['GcpIntegrationsVpcAccessArgs']]):
        pulumi.set(self, "vpc_access", value)


class GcpIntegrations(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 alloy_db: Optional[pulumi.Input[Union['GcpIntegrationsAlloyDbArgs', 'GcpIntegrationsAlloyDbArgsDict']]] = None,
                 app_engine: Optional[pulumi.Input[Union['GcpIntegrationsAppEngineArgs', 'GcpIntegrationsAppEngineArgsDict']]] = None,
                 big_query: Optional[pulumi.Input[Union['GcpIntegrationsBigQueryArgs', 'GcpIntegrationsBigQueryArgsDict']]] = None,
                 big_table: Optional[pulumi.Input[Union['GcpIntegrationsBigTableArgs', 'GcpIntegrationsBigTableArgsDict']]] = None,
                 composer: Optional[pulumi.Input[Union['GcpIntegrationsComposerArgs', 'GcpIntegrationsComposerArgsDict']]] = None,
                 data_flow: Optional[pulumi.Input[Union['GcpIntegrationsDataFlowArgs', 'GcpIntegrationsDataFlowArgsDict']]] = None,
                 data_proc: Optional[pulumi.Input[Union['GcpIntegrationsDataProcArgs', 'GcpIntegrationsDataProcArgsDict']]] = None,
                 data_store: Optional[pulumi.Input[Union['GcpIntegrationsDataStoreArgs', 'GcpIntegrationsDataStoreArgsDict']]] = None,
                 fire_base_database: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseDatabaseArgs', 'GcpIntegrationsFireBaseDatabaseArgsDict']]] = None,
                 fire_base_hosting: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseHostingArgs', 'GcpIntegrationsFireBaseHostingArgsDict']]] = None,
                 fire_base_storage: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseStorageArgs', 'GcpIntegrationsFireBaseStorageArgsDict']]] = None,
                 fire_store: Optional[pulumi.Input[Union['GcpIntegrationsFireStoreArgs', 'GcpIntegrationsFireStoreArgsDict']]] = None,
                 functions: Optional[pulumi.Input[Union['GcpIntegrationsFunctionsArgs', 'GcpIntegrationsFunctionsArgsDict']]] = None,
                 interconnect: Optional[pulumi.Input[Union['GcpIntegrationsInterconnectArgs', 'GcpIntegrationsInterconnectArgsDict']]] = None,
                 kubernetes: Optional[pulumi.Input[Union['GcpIntegrationsKubernetesArgs', 'GcpIntegrationsKubernetesArgsDict']]] = None,
                 linked_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancing: Optional[pulumi.Input[Union['GcpIntegrationsLoadBalancingArgs', 'GcpIntegrationsLoadBalancingArgsDict']]] = None,
                 mem_cache: Optional[pulumi.Input[Union['GcpIntegrationsMemCacheArgs', 'GcpIntegrationsMemCacheArgsDict']]] = None,
                 pub_sub: Optional[pulumi.Input[Union['GcpIntegrationsPubSubArgs', 'GcpIntegrationsPubSubArgsDict']]] = None,
                 redis: Optional[pulumi.Input[Union['GcpIntegrationsRedisArgs', 'GcpIntegrationsRedisArgsDict']]] = None,
                 router: Optional[pulumi.Input[Union['GcpIntegrationsRouterArgs', 'GcpIntegrationsRouterArgsDict']]] = None,
                 run: Optional[pulumi.Input[Union['GcpIntegrationsRunArgs', 'GcpIntegrationsRunArgsDict']]] = None,
                 spanner: Optional[pulumi.Input[Union['GcpIntegrationsSpannerArgs', 'GcpIntegrationsSpannerArgsDict']]] = None,
                 sql: Optional[pulumi.Input[Union['GcpIntegrationsSqlArgs', 'GcpIntegrationsSqlArgsDict']]] = None,
                 storage: Optional[pulumi.Input[Union['GcpIntegrationsStorageArgs', 'GcpIntegrationsStorageArgsDict']]] = None,
                 virtual_machines: Optional[pulumi.Input[Union['GcpIntegrationsVirtualMachinesArgs', 'GcpIntegrationsVirtualMachinesArgsDict']]] = None,
                 vpc_access: Optional[pulumi.Input[Union['GcpIntegrationsVpcAccessArgs', 'GcpIntegrationsVpcAccessArgsDict']]] = None,
                 __props__=None):
        """
        Use this resource to integrate GCP services with New Relic.

        ## Prerequisite

        Setup is required for this resource to work properly. This resource assumes you have linked a GCP account to New Relic and configured it to pull metrics from GCP.

        New Relic doesn't automatically receive metrics from GCP services, so this resource can be used to configure integrations to those services.

        ## Example Usage

        Leave an integration block empty to use its default configuration. You can also use the full example, including the GCP set up, found in our guides.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.cloud.GcpLinkAccount("foo",
            name="example",
            project_id="<Your GCP project ID>")
        foo1 = newrelic.cloud.GcpIntegrations("foo1",
            linked_account_id=foo.id,
            app_engine={
                "metrics_polling_interval": 300,
            },
            big_query={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            big_table={
                "metrics_polling_interval": 300,
            },
            composer={
                "metrics_polling_interval": 300,
            },
            data_flow={
                "metrics_polling_interval": 300,
            },
            data_proc={
                "metrics_polling_interval": 300,
            },
            data_store={
                "metrics_polling_interval": 300,
            },
            fire_base_database={
                "metrics_polling_interval": 300,
            },
            fire_base_hosting={
                "metrics_polling_interval": 300,
            },
            fire_base_storage={
                "metrics_polling_interval": 300,
            },
            fire_store={
                "metrics_polling_interval": 300,
            },
            functions={
                "metrics_polling_interval": 300,
            },
            interconnect={
                "metrics_polling_interval": 300,
            },
            kubernetes={
                "metrics_polling_interval": 300,
            },
            load_balancing={
                "metrics_polling_interval": 300,
            },
            mem_cache={
                "metrics_polling_interval": 300,
            },
            pub_sub={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            redis={
                "metrics_polling_interval": 300,
            },
            router={
                "metrics_polling_interval": 300,
            },
            run={
                "metrics_polling_interval": 300,
            },
            spanner={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            sql={
                "metrics_polling_interval": 300,
            },
            storage={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            virtual_machines={
                "metrics_polling_interval": 300,
            },
            vpc_access={
                "metrics_polling_interval": 300,
            })
        ```

        ## Import

        Linked GCP account integrations can be imported using the `id`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:cloud/gcpIntegrations:GcpIntegrations foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Union['GcpIntegrationsAlloyDbArgs', 'GcpIntegrationsAlloyDbArgsDict']] alloy_db: Alloy DB integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsAppEngineArgs', 'GcpIntegrationsAppEngineArgsDict']] app_engine: App Engine integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsBigQueryArgs', 'GcpIntegrationsBigQueryArgsDict']] big_query: Biq Query integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsBigTableArgs', 'GcpIntegrationsBigTableArgsDict']] big_table: Big Table. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsComposerArgs', 'GcpIntegrationsComposerArgsDict']] composer: Composer integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsDataFlowArgs', 'GcpIntegrationsDataFlowArgsDict']] data_flow: Data Flow integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsDataProcArgs', 'GcpIntegrationsDataProcArgsDict']] data_proc: Data Proc integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsDataStoreArgs', 'GcpIntegrationsDataStoreArgsDict']] data_store: Data Store integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireBaseDatabaseArgs', 'GcpIntegrationsFireBaseDatabaseArgsDict']] fire_base_database: Fire Base Database integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireBaseHostingArgs', 'GcpIntegrationsFireBaseHostingArgsDict']] fire_base_hosting: Fire Base Hosting integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireBaseStorageArgs', 'GcpIntegrationsFireBaseStorageArgsDict']] fire_base_storage: Fire Base Storage integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireStoreArgs', 'GcpIntegrationsFireStoreArgsDict']] fire_store: Fire Store integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFunctionsArgs', 'GcpIntegrationsFunctionsArgsDict']] functions: Functions integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsInterconnectArgs', 'GcpIntegrationsInterconnectArgsDict']] interconnect: Interconnect integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsKubernetesArgs', 'GcpIntegrationsKubernetesArgsDict']] kubernetes: Kubernetes integration. See Integration blocks below for details.
        :param pulumi.Input[builtins.str] linked_account_id: The ID of the linked GCP account in New Relic.
               
               The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        :param pulumi.Input[Union['GcpIntegrationsLoadBalancingArgs', 'GcpIntegrationsLoadBalancingArgsDict']] load_balancing: Load Balancing integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsMemCacheArgs', 'GcpIntegrationsMemCacheArgsDict']] mem_cache: Mem cache integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsPubSubArgs', 'GcpIntegrationsPubSubArgsDict']] pub_sub: Pub/Sub integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsRedisArgs', 'GcpIntegrationsRedisArgsDict']] redis: Redis integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsRouterArgs', 'GcpIntegrationsRouterArgsDict']] router: Router integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsRunArgs', 'GcpIntegrationsRunArgsDict']] run: Run integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsSpannerArgs', 'GcpIntegrationsSpannerArgsDict']] spanner: Spanner integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsSqlArgs', 'GcpIntegrationsSqlArgsDict']] sql: SQL integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsStorageArgs', 'GcpIntegrationsStorageArgsDict']] storage: Storage integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsVirtualMachinesArgs', 'GcpIntegrationsVirtualMachinesArgsDict']] virtual_machines: Virtual machines integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsVpcAccessArgs', 'GcpIntegrationsVpcAccessArgsDict']] vpc_access: VPC Access integration. See Integration blocks below for details.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GcpIntegrationsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to integrate GCP services with New Relic.

        ## Prerequisite

        Setup is required for this resource to work properly. This resource assumes you have linked a GCP account to New Relic and configured it to pull metrics from GCP.

        New Relic doesn't automatically receive metrics from GCP services, so this resource can be used to configure integrations to those services.

        ## Example Usage

        Leave an integration block empty to use its default configuration. You can also use the full example, including the GCP set up, found in our guides.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.cloud.GcpLinkAccount("foo",
            name="example",
            project_id="<Your GCP project ID>")
        foo1 = newrelic.cloud.GcpIntegrations("foo1",
            linked_account_id=foo.id,
            app_engine={
                "metrics_polling_interval": 300,
            },
            big_query={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            big_table={
                "metrics_polling_interval": 300,
            },
            composer={
                "metrics_polling_interval": 300,
            },
            data_flow={
                "metrics_polling_interval": 300,
            },
            data_proc={
                "metrics_polling_interval": 300,
            },
            data_store={
                "metrics_polling_interval": 300,
            },
            fire_base_database={
                "metrics_polling_interval": 300,
            },
            fire_base_hosting={
                "metrics_polling_interval": 300,
            },
            fire_base_storage={
                "metrics_polling_interval": 300,
            },
            fire_store={
                "metrics_polling_interval": 300,
            },
            functions={
                "metrics_polling_interval": 300,
            },
            interconnect={
                "metrics_polling_interval": 300,
            },
            kubernetes={
                "metrics_polling_interval": 300,
            },
            load_balancing={
                "metrics_polling_interval": 300,
            },
            mem_cache={
                "metrics_polling_interval": 300,
            },
            pub_sub={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            redis={
                "metrics_polling_interval": 300,
            },
            router={
                "metrics_polling_interval": 300,
            },
            run={
                "metrics_polling_interval": 300,
            },
            spanner={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            sql={
                "metrics_polling_interval": 300,
            },
            storage={
                "metrics_polling_interval": 300,
                "fetch_tags": True,
            },
            virtual_machines={
                "metrics_polling_interval": 300,
            },
            vpc_access={
                "metrics_polling_interval": 300,
            })
        ```

        ## Import

        Linked GCP account integrations can be imported using the `id`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:cloud/gcpIntegrations:GcpIntegrations foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param GcpIntegrationsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GcpIntegrationsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[builtins.str]] = None,
                 alloy_db: Optional[pulumi.Input[Union['GcpIntegrationsAlloyDbArgs', 'GcpIntegrationsAlloyDbArgsDict']]] = None,
                 app_engine: Optional[pulumi.Input[Union['GcpIntegrationsAppEngineArgs', 'GcpIntegrationsAppEngineArgsDict']]] = None,
                 big_query: Optional[pulumi.Input[Union['GcpIntegrationsBigQueryArgs', 'GcpIntegrationsBigQueryArgsDict']]] = None,
                 big_table: Optional[pulumi.Input[Union['GcpIntegrationsBigTableArgs', 'GcpIntegrationsBigTableArgsDict']]] = None,
                 composer: Optional[pulumi.Input[Union['GcpIntegrationsComposerArgs', 'GcpIntegrationsComposerArgsDict']]] = None,
                 data_flow: Optional[pulumi.Input[Union['GcpIntegrationsDataFlowArgs', 'GcpIntegrationsDataFlowArgsDict']]] = None,
                 data_proc: Optional[pulumi.Input[Union['GcpIntegrationsDataProcArgs', 'GcpIntegrationsDataProcArgsDict']]] = None,
                 data_store: Optional[pulumi.Input[Union['GcpIntegrationsDataStoreArgs', 'GcpIntegrationsDataStoreArgsDict']]] = None,
                 fire_base_database: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseDatabaseArgs', 'GcpIntegrationsFireBaseDatabaseArgsDict']]] = None,
                 fire_base_hosting: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseHostingArgs', 'GcpIntegrationsFireBaseHostingArgsDict']]] = None,
                 fire_base_storage: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseStorageArgs', 'GcpIntegrationsFireBaseStorageArgsDict']]] = None,
                 fire_store: Optional[pulumi.Input[Union['GcpIntegrationsFireStoreArgs', 'GcpIntegrationsFireStoreArgsDict']]] = None,
                 functions: Optional[pulumi.Input[Union['GcpIntegrationsFunctionsArgs', 'GcpIntegrationsFunctionsArgsDict']]] = None,
                 interconnect: Optional[pulumi.Input[Union['GcpIntegrationsInterconnectArgs', 'GcpIntegrationsInterconnectArgsDict']]] = None,
                 kubernetes: Optional[pulumi.Input[Union['GcpIntegrationsKubernetesArgs', 'GcpIntegrationsKubernetesArgsDict']]] = None,
                 linked_account_id: Optional[pulumi.Input[builtins.str]] = None,
                 load_balancing: Optional[pulumi.Input[Union['GcpIntegrationsLoadBalancingArgs', 'GcpIntegrationsLoadBalancingArgsDict']]] = None,
                 mem_cache: Optional[pulumi.Input[Union['GcpIntegrationsMemCacheArgs', 'GcpIntegrationsMemCacheArgsDict']]] = None,
                 pub_sub: Optional[pulumi.Input[Union['GcpIntegrationsPubSubArgs', 'GcpIntegrationsPubSubArgsDict']]] = None,
                 redis: Optional[pulumi.Input[Union['GcpIntegrationsRedisArgs', 'GcpIntegrationsRedisArgsDict']]] = None,
                 router: Optional[pulumi.Input[Union['GcpIntegrationsRouterArgs', 'GcpIntegrationsRouterArgsDict']]] = None,
                 run: Optional[pulumi.Input[Union['GcpIntegrationsRunArgs', 'GcpIntegrationsRunArgsDict']]] = None,
                 spanner: Optional[pulumi.Input[Union['GcpIntegrationsSpannerArgs', 'GcpIntegrationsSpannerArgsDict']]] = None,
                 sql: Optional[pulumi.Input[Union['GcpIntegrationsSqlArgs', 'GcpIntegrationsSqlArgsDict']]] = None,
                 storage: Optional[pulumi.Input[Union['GcpIntegrationsStorageArgs', 'GcpIntegrationsStorageArgsDict']]] = None,
                 virtual_machines: Optional[pulumi.Input[Union['GcpIntegrationsVirtualMachinesArgs', 'GcpIntegrationsVirtualMachinesArgsDict']]] = None,
                 vpc_access: Optional[pulumi.Input[Union['GcpIntegrationsVpcAccessArgs', 'GcpIntegrationsVpcAccessArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GcpIntegrationsArgs.__new__(GcpIntegrationsArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["alloy_db"] = alloy_db
            __props__.__dict__["app_engine"] = app_engine
            __props__.__dict__["big_query"] = big_query
            __props__.__dict__["big_table"] = big_table
            __props__.__dict__["composer"] = composer
            __props__.__dict__["data_flow"] = data_flow
            __props__.__dict__["data_proc"] = data_proc
            __props__.__dict__["data_store"] = data_store
            __props__.__dict__["fire_base_database"] = fire_base_database
            __props__.__dict__["fire_base_hosting"] = fire_base_hosting
            __props__.__dict__["fire_base_storage"] = fire_base_storage
            __props__.__dict__["fire_store"] = fire_store
            __props__.__dict__["functions"] = functions
            __props__.__dict__["interconnect"] = interconnect
            __props__.__dict__["kubernetes"] = kubernetes
            if linked_account_id is None and not opts.urn:
                raise TypeError("Missing required property 'linked_account_id'")
            __props__.__dict__["linked_account_id"] = linked_account_id
            __props__.__dict__["load_balancing"] = load_balancing
            __props__.__dict__["mem_cache"] = mem_cache
            __props__.__dict__["pub_sub"] = pub_sub
            __props__.__dict__["redis"] = redis
            __props__.__dict__["router"] = router
            __props__.__dict__["run"] = run
            __props__.__dict__["spanner"] = spanner
            __props__.__dict__["sql"] = sql
            __props__.__dict__["storage"] = storage
            __props__.__dict__["virtual_machines"] = virtual_machines
            __props__.__dict__["vpc_access"] = vpc_access
        super(GcpIntegrations, __self__).__init__(
            'newrelic:cloud/gcpIntegrations:GcpIntegrations',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[builtins.str]] = None,
            alloy_db: Optional[pulumi.Input[Union['GcpIntegrationsAlloyDbArgs', 'GcpIntegrationsAlloyDbArgsDict']]] = None,
            app_engine: Optional[pulumi.Input[Union['GcpIntegrationsAppEngineArgs', 'GcpIntegrationsAppEngineArgsDict']]] = None,
            big_query: Optional[pulumi.Input[Union['GcpIntegrationsBigQueryArgs', 'GcpIntegrationsBigQueryArgsDict']]] = None,
            big_table: Optional[pulumi.Input[Union['GcpIntegrationsBigTableArgs', 'GcpIntegrationsBigTableArgsDict']]] = None,
            composer: Optional[pulumi.Input[Union['GcpIntegrationsComposerArgs', 'GcpIntegrationsComposerArgsDict']]] = None,
            data_flow: Optional[pulumi.Input[Union['GcpIntegrationsDataFlowArgs', 'GcpIntegrationsDataFlowArgsDict']]] = None,
            data_proc: Optional[pulumi.Input[Union['GcpIntegrationsDataProcArgs', 'GcpIntegrationsDataProcArgsDict']]] = None,
            data_store: Optional[pulumi.Input[Union['GcpIntegrationsDataStoreArgs', 'GcpIntegrationsDataStoreArgsDict']]] = None,
            fire_base_database: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseDatabaseArgs', 'GcpIntegrationsFireBaseDatabaseArgsDict']]] = None,
            fire_base_hosting: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseHostingArgs', 'GcpIntegrationsFireBaseHostingArgsDict']]] = None,
            fire_base_storage: Optional[pulumi.Input[Union['GcpIntegrationsFireBaseStorageArgs', 'GcpIntegrationsFireBaseStorageArgsDict']]] = None,
            fire_store: Optional[pulumi.Input[Union['GcpIntegrationsFireStoreArgs', 'GcpIntegrationsFireStoreArgsDict']]] = None,
            functions: Optional[pulumi.Input[Union['GcpIntegrationsFunctionsArgs', 'GcpIntegrationsFunctionsArgsDict']]] = None,
            interconnect: Optional[pulumi.Input[Union['GcpIntegrationsInterconnectArgs', 'GcpIntegrationsInterconnectArgsDict']]] = None,
            kubernetes: Optional[pulumi.Input[Union['GcpIntegrationsKubernetesArgs', 'GcpIntegrationsKubernetesArgsDict']]] = None,
            linked_account_id: Optional[pulumi.Input[builtins.str]] = None,
            load_balancing: Optional[pulumi.Input[Union['GcpIntegrationsLoadBalancingArgs', 'GcpIntegrationsLoadBalancingArgsDict']]] = None,
            mem_cache: Optional[pulumi.Input[Union['GcpIntegrationsMemCacheArgs', 'GcpIntegrationsMemCacheArgsDict']]] = None,
            pub_sub: Optional[pulumi.Input[Union['GcpIntegrationsPubSubArgs', 'GcpIntegrationsPubSubArgsDict']]] = None,
            redis: Optional[pulumi.Input[Union['GcpIntegrationsRedisArgs', 'GcpIntegrationsRedisArgsDict']]] = None,
            router: Optional[pulumi.Input[Union['GcpIntegrationsRouterArgs', 'GcpIntegrationsRouterArgsDict']]] = None,
            run: Optional[pulumi.Input[Union['GcpIntegrationsRunArgs', 'GcpIntegrationsRunArgsDict']]] = None,
            spanner: Optional[pulumi.Input[Union['GcpIntegrationsSpannerArgs', 'GcpIntegrationsSpannerArgsDict']]] = None,
            sql: Optional[pulumi.Input[Union['GcpIntegrationsSqlArgs', 'GcpIntegrationsSqlArgsDict']]] = None,
            storage: Optional[pulumi.Input[Union['GcpIntegrationsStorageArgs', 'GcpIntegrationsStorageArgsDict']]] = None,
            virtual_machines: Optional[pulumi.Input[Union['GcpIntegrationsVirtualMachinesArgs', 'GcpIntegrationsVirtualMachinesArgsDict']]] = None,
            vpc_access: Optional[pulumi.Input[Union['GcpIntegrationsVpcAccessArgs', 'GcpIntegrationsVpcAccessArgsDict']]] = None) -> 'GcpIntegrations':
        """
        Get an existing GcpIntegrations resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_id: The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        :param pulumi.Input[Union['GcpIntegrationsAlloyDbArgs', 'GcpIntegrationsAlloyDbArgsDict']] alloy_db: Alloy DB integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsAppEngineArgs', 'GcpIntegrationsAppEngineArgsDict']] app_engine: App Engine integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsBigQueryArgs', 'GcpIntegrationsBigQueryArgsDict']] big_query: Biq Query integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsBigTableArgs', 'GcpIntegrationsBigTableArgsDict']] big_table: Big Table. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsComposerArgs', 'GcpIntegrationsComposerArgsDict']] composer: Composer integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsDataFlowArgs', 'GcpIntegrationsDataFlowArgsDict']] data_flow: Data Flow integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsDataProcArgs', 'GcpIntegrationsDataProcArgsDict']] data_proc: Data Proc integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsDataStoreArgs', 'GcpIntegrationsDataStoreArgsDict']] data_store: Data Store integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireBaseDatabaseArgs', 'GcpIntegrationsFireBaseDatabaseArgsDict']] fire_base_database: Fire Base Database integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireBaseHostingArgs', 'GcpIntegrationsFireBaseHostingArgsDict']] fire_base_hosting: Fire Base Hosting integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireBaseStorageArgs', 'GcpIntegrationsFireBaseStorageArgsDict']] fire_base_storage: Fire Base Storage integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFireStoreArgs', 'GcpIntegrationsFireStoreArgsDict']] fire_store: Fire Store integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsFunctionsArgs', 'GcpIntegrationsFunctionsArgsDict']] functions: Functions integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsInterconnectArgs', 'GcpIntegrationsInterconnectArgsDict']] interconnect: Interconnect integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsKubernetesArgs', 'GcpIntegrationsKubernetesArgsDict']] kubernetes: Kubernetes integration. See Integration blocks below for details.
        :param pulumi.Input[builtins.str] linked_account_id: The ID of the linked GCP account in New Relic.
               
               The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        :param pulumi.Input[Union['GcpIntegrationsLoadBalancingArgs', 'GcpIntegrationsLoadBalancingArgsDict']] load_balancing: Load Balancing integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsMemCacheArgs', 'GcpIntegrationsMemCacheArgsDict']] mem_cache: Mem cache integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsPubSubArgs', 'GcpIntegrationsPubSubArgsDict']] pub_sub: Pub/Sub integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsRedisArgs', 'GcpIntegrationsRedisArgsDict']] redis: Redis integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsRouterArgs', 'GcpIntegrationsRouterArgsDict']] router: Router integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsRunArgs', 'GcpIntegrationsRunArgsDict']] run: Run integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsSpannerArgs', 'GcpIntegrationsSpannerArgsDict']] spanner: Spanner integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsSqlArgs', 'GcpIntegrationsSqlArgsDict']] sql: SQL integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsStorageArgs', 'GcpIntegrationsStorageArgsDict']] storage: Storage integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsVirtualMachinesArgs', 'GcpIntegrationsVirtualMachinesArgsDict']] virtual_machines: Virtual machines integration. See Integration blocks below for details.
        :param pulumi.Input[Union['GcpIntegrationsVpcAccessArgs', 'GcpIntegrationsVpcAccessArgsDict']] vpc_access: VPC Access integration. See Integration blocks below for details.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GcpIntegrationsState.__new__(_GcpIntegrationsState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["alloy_db"] = alloy_db
        __props__.__dict__["app_engine"] = app_engine
        __props__.__dict__["big_query"] = big_query
        __props__.__dict__["big_table"] = big_table
        __props__.__dict__["composer"] = composer
        __props__.__dict__["data_flow"] = data_flow
        __props__.__dict__["data_proc"] = data_proc
        __props__.__dict__["data_store"] = data_store
        __props__.__dict__["fire_base_database"] = fire_base_database
        __props__.__dict__["fire_base_hosting"] = fire_base_hosting
        __props__.__dict__["fire_base_storage"] = fire_base_storage
        __props__.__dict__["fire_store"] = fire_store
        __props__.__dict__["functions"] = functions
        __props__.__dict__["interconnect"] = interconnect
        __props__.__dict__["kubernetes"] = kubernetes
        __props__.__dict__["linked_account_id"] = linked_account_id
        __props__.__dict__["load_balancing"] = load_balancing
        __props__.__dict__["mem_cache"] = mem_cache
        __props__.__dict__["pub_sub"] = pub_sub
        __props__.__dict__["redis"] = redis
        __props__.__dict__["router"] = router
        __props__.__dict__["run"] = run
        __props__.__dict__["spanner"] = spanner
        __props__.__dict__["sql"] = sql
        __props__.__dict__["storage"] = storage
        __props__.__dict__["virtual_machines"] = virtual_machines
        __props__.__dict__["vpc_access"] = vpc_access
        return GcpIntegrations(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[builtins.str]:
        """
        The New Relic account ID to operate on.  This allows the user to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
        """
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="alloyDb")
    def alloy_db(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsAlloyDb']]:
        """
        Alloy DB integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "alloy_db")

    @property
    @pulumi.getter(name="appEngine")
    def app_engine(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsAppEngine']]:
        """
        App Engine integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "app_engine")

    @property
    @pulumi.getter(name="bigQuery")
    def big_query(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsBigQuery']]:
        """
        Biq Query integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "big_query")

    @property
    @pulumi.getter(name="bigTable")
    def big_table(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsBigTable']]:
        """
        Big Table. See Integration blocks below for details.
        """
        return pulumi.get(self, "big_table")

    @property
    @pulumi.getter
    def composer(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsComposer']]:
        """
        Composer integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "composer")

    @property
    @pulumi.getter(name="dataFlow")
    def data_flow(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsDataFlow']]:
        """
        Data Flow integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_flow")

    @property
    @pulumi.getter(name="dataProc")
    def data_proc(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsDataProc']]:
        """
        Data Proc integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_proc")

    @property
    @pulumi.getter(name="dataStore")
    def data_store(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsDataStore']]:
        """
        Data Store integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "data_store")

    @property
    @pulumi.getter(name="fireBaseDatabase")
    def fire_base_database(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsFireBaseDatabase']]:
        """
        Fire Base Database integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_database")

    @property
    @pulumi.getter(name="fireBaseHosting")
    def fire_base_hosting(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsFireBaseHosting']]:
        """
        Fire Base Hosting integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_hosting")

    @property
    @pulumi.getter(name="fireBaseStorage")
    def fire_base_storage(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsFireBaseStorage']]:
        """
        Fire Base Storage integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_base_storage")

    @property
    @pulumi.getter(name="fireStore")
    def fire_store(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsFireStore']]:
        """
        Fire Store integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "fire_store")

    @property
    @pulumi.getter
    def functions(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsFunctions']]:
        """
        Functions integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "functions")

    @property
    @pulumi.getter
    def interconnect(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsInterconnect']]:
        """
        Interconnect integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "interconnect")

    @property
    @pulumi.getter
    def kubernetes(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsKubernetes']]:
        """
        Kubernetes integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "kubernetes")

    @property
    @pulumi.getter(name="linkedAccountId")
    def linked_account_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the linked GCP account in New Relic.

        The following arguments/integration blocks are intended to be used with a minimum `metrics_polling_interval` of 300 seconds.
        """
        return pulumi.get(self, "linked_account_id")

    @property
    @pulumi.getter(name="loadBalancing")
    def load_balancing(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsLoadBalancing']]:
        """
        Load Balancing integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "load_balancing")

    @property
    @pulumi.getter(name="memCache")
    def mem_cache(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsMemCache']]:
        """
        Mem cache integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "mem_cache")

    @property
    @pulumi.getter(name="pubSub")
    def pub_sub(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsPubSub']]:
        """
        Pub/Sub integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "pub_sub")

    @property
    @pulumi.getter
    def redis(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsRedis']]:
        """
        Redis integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "redis")

    @property
    @pulumi.getter
    def router(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsRouter']]:
        """
        Router integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "router")

    @property
    @pulumi.getter
    def run(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsRun']]:
        """
        Run integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "run")

    @property
    @pulumi.getter
    def spanner(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsSpanner']]:
        """
        Spanner integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "spanner")

    @property
    @pulumi.getter
    def sql(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsSql']]:
        """
        SQL integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "sql")

    @property
    @pulumi.getter
    def storage(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsStorage']]:
        """
        Storage integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "storage")

    @property
    @pulumi.getter(name="virtualMachines")
    def virtual_machines(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsVirtualMachines']]:
        """
        Virtual machines integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "virtual_machines")

    @property
    @pulumi.getter(name="vpcAccess")
    def vpc_access(self) -> pulumi.Output[Optional['outputs.GcpIntegrationsVpcAccess']]:
        """
        VPC Access integration. See Integration blocks below for details.
        """
        return pulumi.get(self, "vpc_access")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSecureCredentialResult',
    'AwaitableGetSecureCredentialResult',
    'get_secure_credential',
    'get_secure_credential_output',
]

@pulumi.output_type
class GetSecureCredentialResult:
    """
    A collection of values returned by getSecureCredential.
    """
    def __init__(__self__, account_id=None, description=None, id=None, key=None, last_updated=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> builtins.str:
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        The secure credential's description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> builtins.str:
        """
        The time the secure credential was last updated.
        """
        return pulumi.get(self, "last_updated")


class AwaitableGetSecureCredentialResult(GetSecureCredentialResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSecureCredentialResult(
            account_id=self.account_id,
            description=self.description,
            id=self.id,
            key=self.key,
            last_updated=self.last_updated)


def get_secure_credential(account_id: Optional[builtins.str] = None,
                          key: Optional[builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSecureCredentialResult:
    """
    Use this data source to get information about a specific Synthetics secure credential in New Relic that already exists.

    Note that the secure credential's value is not returned as an attribute for security reasons.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.synthetics.get_secure_credential(key="MY_KEY")
    ```


    :param builtins.str account_id: The account in New Relic associated with the secure credential. Defaults to the account associated with the API key used.
    :param builtins.str key: The secure credential's key name.  Regardless of the case used in the configuration, the provider will provide an upcased key to the underlying API.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['key'] = key
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:synthetics/getSecureCredential:getSecureCredential', __args__, opts=opts, typ=GetSecureCredentialResult).value

    return AwaitableGetSecureCredentialResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        key=pulumi.get(__ret__, 'key'),
        last_updated=pulumi.get(__ret__, 'last_updated'))
def get_secure_credential_output(account_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                 key: Optional[pulumi.Input[builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSecureCredentialResult]:
    """
    Use this data source to get information about a specific Synthetics secure credential in New Relic that already exists.

    Note that the secure credential's value is not returned as an attribute for security reasons.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    foo = newrelic.synthetics.get_secure_credential(key="MY_KEY")
    ```


    :param builtins.str account_id: The account in New Relic associated with the secure credential. Defaults to the account associated with the API key used.
    :param builtins.str key: The secure credential's key name.  Regardless of the case used in the configuration, the provider will provide an upcased key to the underlying API.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['key'] = key
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:synthetics/getSecureCredential:getSecureCredential', __args__, opts=opts, typ=GetSecureCredentialResult)
    return __ret__.apply(lambda __response__: GetSecureCredentialResult(
        account_id=pulumi.get(__response__, 'account_id'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        key=pulumi.get(__response__, 'key'),
        last_updated=pulumi.get(__response__, 'last_updated')))
